Trait PopenExt
Source pub trait PopenExt {
// Required method
fn send_signal(&self, signal: i32) -> Result<()>;
}
Unix-specific extension methods for Popen
Send the specified signal to the child process.
The signal numbers are best obtained from the libc
crate.
If the child process is known to have finished (due to e.g.
a previous call to wait or poll), this will do
nothing and return Ok.